Learn R Programming

occTest (version 0.1.1)

.cc_urb_occTest: Flag values in urban areas (based on coordinate cleaner but modified for occTest to deliver it quitely)

Description

flags values for urban areas

Usage

.cc_urb_occTest(
  x,
  lon = "decimallongitude",
  lat = "decimallatitude",
  ref = NULL,
  value = "clean",
  verbose = FALSE,
  outdir
)

Value

a clean data.frame

Arguments

x

Data.frame of species occurrences

lon

character. Column name in x with decimal longitude values

lat

character. Column name in x with decimal latitude values

value

character string. Defining the output value. See value.

verbose

logical. If TRUE reports the name of the test and the number of records flagged

outdir

output directory

a

SpatialPolygonsDataFrame. Providing the geographic gazetteer with the urban areas. See details. By default rnaturalearth::ne_download(scale = 'medium', type = 'urban_areas'). Can be any SpatialPolygonsDataframe, but the structure must be identical to rnaturalearth::ne_download().

Author

A Zizka (original function) Josep M Serra-Diaz (adaptation to occTest pep.serradiaz@agroparistech.fr)

References

CoordinateCleaner package

See Also

cc_urb