Learn R Programming

occTest (version 0.1.1)

.checkdatastr2: Check data structure

Description

Verify that all main data fields are correctly structured

Usage

.checkdatastr2(dat, xf, yf, verbose = FALSE)

Value

Original dataframe, dat. Used primarily to generate warning messages.

Arguments

dat

A dataframe containing occurrence data for checking.

xf

character. Name of the field where the x coordinate is stored (typically longitude). Default is x.field

yf

character. Name of the field where the y coordinate is stored (typically latitude). Default is y.field

verbose

logical. Print messages? Defaults to FALSE

Author

Mark Robertson and Vernon Visser (original function), Josep M Serra Diaz (modifs)

Details

Inspired by checkdatastr but modified (hence number 2 after the function original name)

See Also

Other checks: .addmainfields2(), .check.geospatial.data(), .checkfields(), .status.tracker.and.escaping()