Learn R Programming

occTest (version 0.1.1)

.ne_download_occTest: Download quitely from neearth data (modified from original package)

Description

download from Natural Earth the country checklist

Usage

.ne_download_occTest(
  scale = 110,
  type = "countries",
  category = c("cultural", "physical", "raster"),
  destdir = tempdir(),
  load = TRUE,
  returnclass = c("sp", "sf")
)

Value

spatial object or raster

Arguments

scale

Data.frame of species occurrences

type

the field in the dataframe containing the x coordinates

category

the field in the dataframe containing the y coordinates

load

Raster of human influence index

desetdir

proj4string argument for dataframe

Author

Andy South (southandy@gmail.com) rnaturalearth; Josep M Serra Diaz (modifs)

See Also

\[linkrnaturalearth]ne_download