Learn R Programming

occTest (version 0.1.1)

.nearestcell3: SeaLand reassignment

Description

SeaLand reassignment

Usage

.nearestcell3(dat, rst, xf, yf, verbose = FALSE)

Value

list

Arguments

dat

Data.frame of species occurrences

rst

raster class object.

xf

the field in the data frame containing the x coordinators

yf

the field in the data frame containing the y coordinators

verbose

logical. Print messages? Default FALSE

Author

Mark Robertson and Veron Visser (original biogeo-package), Josep M Serra-Diaz (modifs)

Details

(function inspired in nearestcell in biogeo but modified

See Also

original code at nearestcell

Other analysis: centroidDetection(), countryStatusRangeAnalysis(), duplicatesexcludeAnalysis(), geoEnvAccuracy(), humanDetection()