flags values for urban areas
.cc_urb_occTest(
x,
lon = "decimallongitude",
lat = "decimallatitude",
ref = NULL,
value = "clean",
verbose = FALSE,
outdir
)a clean data.frame
Data.frame of species occurrences
character. Column name in x with decimal longitude values
character. Column name in x with decimal latitude values
character string. Defining the output value. See value.
logical. If TRUE reports the name of the test and the number of records flagged
output directory
SpatialPolygonsDataFrame. Providing the geographic gazetteer with the urban areas. See details. By default rnaturalearth::ne_download(scale = 'medium', type = 'urban_areas'). Can be any SpatialPolygonsDataframe, but the structure must be identical to rnaturalearth::ne_download().
A Zizka (original function) Josep M Serra-Diaz (adaptation to occTest pep.serradiaz@agroparistech.fr)
CoordinateCleaner package
cc_urb