Verify that all main data fields are correctly structured
.checkdatastr2(dat, xf, yf, verbose = FALSE)Original dataframe, dat. Used primarily to generate warning messages.
A dataframe containing occurrence data for checking.
character. Name of the field where the x coordinate is stored (typically longitude). Default is x.field
character. Name of the field where the y coordinate is stored (typically latitude). Default is y.field
logical. Print messages? Defaults to FALSE
Mark Robertson and Vernon Visser (original function), Josep M Serra Diaz (modifs)
Inspired by checkdatastr but modified (hence number 2 after the function original name)
Other checks:
.addmainfields2(),
.check.geospatial.data(),
.checkfields(),
.status.tracker.and.escaping()