download from Natural Earth the country checklist
.ne_download_occTest(
scale = 110,
type = "countries",
category = c("cultural", "physical", "raster"),
destdir = tempdir(),
load = TRUE,
returnclass = c("sp", "sf")
)spatial object or raster
Data.frame of species occurrences
the field in the dataframe containing the x coordinates
the field in the dataframe containing the y coordinates
Raster of human influence index
proj4string argument for dataframe
Andy South (southandy@gmail.com) rnaturalearth; Josep M Serra Diaz (modifs)
\[linkrnaturalearth]ne_download