SeaLand reassignment
.nearestcell3(dat, rst, xf, yf, verbose = FALSE)list
Data.frame of species occurrences
raster class object.
the field in the data frame containing the x coordinators
the field in the data frame containing the y coordinators
logical. Print messages? Default FALSE
Mark Robertson and Veron Visser (original biogeo-package), Josep M Serra-Diaz (modifs)
(function inspired in nearestcell in biogeo but modified
original code at nearestcell
Other analysis:
centroidDetection(),
countryStatusRangeAnalysis(),
duplicatesexcludeAnalysis(),
geoEnvAccuracy(),
humanDetection()